@@ -122,6 +122,12 @@ MainWindow::MainWindow(QWidget * parent) : QWidget(parent), ui(new Ui::MainWindo
   connect(searchAction, SIGNAL(triggered(bool)), ui->searchField, SLOT(setFocus()));
   addAction(searchAction);
 
+  QAction * togglePreviewAction = new QAction(this);
+  togglePreviewAction->setShortcut(QKeySequence("Ctrl+P"));
+  togglePreviewAction->setShortcutContext(Qt::ApplicationShortcut);
+  connect(togglePreviewAction, SIGNAL(triggered(bool)), ui->cbPreview, SLOT(toggle()));
+  addAction(togglePreviewAction);
+
   searchAction = new QAction(this);
   searchAction->setShortcut(QKeySequence("/"));
   searchAction->setShortcutContext(Qt::ApplicationShortcut);
@@ -718,6 +724,7 @@ void MainWindow::onOkClicked()
 void MainWindow::onCloseClicked()
 {
   TIMING;
+  ENTERING;
   if (_processor.isProcessing() && confirmAbortProcessingOnCloseRequest()) {
     if (_processor.isProcessing()) {
       _pendingActionAfterCurrentProcessing = CloseAction;
@@ -1008,6 +1015,7 @@ void MainWindow::setNoFilter()
 {
   ui->filterParams->setNoFilter();
   ui->previewWidget->disableRightClick();
+  ui->previewWidget->setKeypoints(KeypointList());
   ui->inOutSelector->hide();
   ui->inOutSelector->setState(GmicQt::InputOutputState::Default, false);
   ui->filterName->setVisible(false);
